@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -28,7 +28,8 @@
 #ifndef COMMANDITEMMODEL_H
 #define COMMANDITEMMODEL_H
 
-#include <providers.h>
+#include "providers.h"
+
 #include <QSortFilterProxyModel>
 #include <QAbstractListModel>
 #include <QVariant>
@@ -37,6 +38,7 @@
 class CommandSourceItemModel: public QAbstractListModel
 {
     Q_OBJECT
+
 public:
     explicit CommandSourceItemModel(bool useHistory, QObject *parent = 0);
     virtual ~CommandSourceItemModel();
@@ -57,6 +59,7 @@ public:
     /*! Flag if the history should be shown/stored
      */
     void setUseHistory(bool useHistory);
+
 public slots:
     void rebuild();
     void clearHistory();
@@ -74,6 +77,7 @@ private:
 class CommandItemModel: public QSortFilterProxyModel
 {
     Q_OBJECT
+
 public:
     explicit CommandItemModel(bool useHistory, QObject *parent = 0);
     virtual ~CommandItemModel();
