@@ -6,7 +6,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="14"/>
         <source>Runner Settings</source>
-        <translation>Настройки runner</translation>
+        <translation>Настройки на стартиране на програми</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="20"/>
@@ -46,7 +46,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="74"/>
         <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
-        <translation>&lt;b&gt;Note&lt;/b&gt;: Размерът на приставките от високо ниво е ограничен до 2/3 от височината и ширината на работния плот.</translation>
+        <translation>&lt;b&gt;Забележка&lt;/b&gt;: Размерът на приставките от високо ниво е ограничен до 2/3 от височината и ширината на работния плот.</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="77"/>
@@ -102,19 +102,19 @@
         <translation>Стартер на приложение </translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="106"/>
+        <location filename="../dialog.cpp" line="109"/>
         <source>Configure</source>
         <translation>Настройване</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="110"/>
+        <location filename="../dialog.cpp" line="113"/>
         <source>Clear History</source>
         <translation>Изчистване на историята</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="409"/>
+        <location filename="../dialog.cpp" line="465"/>
         <source>Show/hide runner dialog</source>
-        <translation>Показване/скриване диалог на runner</translation>
+        <translation>Показване/скриване диалог за стартиране на програми</translation>
     </message>
 </context>
 <context>
